==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/sr/sections.php <==
<?php
regGS("Section List", "Листа рубрика");
regGS("Section #$1 \"$2\" updated. (Publication: $3, Issue: $4)", "рубрика #$1 \"$2\" је измењена. (публикација: $3, издање: $4)");
regGS("Go To Articles", "Иди на чланке");
regGS("Add section to all subscriptions.", "Додај рубрику у све претплате.");
regGS("Delete section from all subscriptions.", "Обриши рубрику из свих претплата.");
regGS("A total of $1 subscriptions were updated.", "Укупан број измењених претплата: $1.");
regGS("Name<BR><SMALL>(click to see articles)</SMALL>", "Назив");
regGS("Delete section $1", "Обриши рубрику");
regGS("Adding new section", "Додавање нове рубрике");
regGS("You do not have the right to add sections.", "Немате право да додајете рубрике");
regGS("The section $1 has been successfuly added.", "Рубрика $1 успешно је додата");
regGS("Please check if another section with the same number or URL name does not exist already.", "Проверите да ли друга рубрика са истим бројем или УРЛ именом већ не постоји.");
regGS("Select the section", "Изабери рубрику");
regGS("Delete section", "Обриши рубрику");
regGS("You do not have the right to delete sections.", "Немате право брисања рубрика");
regGS("Are you sure you want to delete the section $1?", "Да ли сте сигурни да желите да обришете рубрику $1? ");
regGS("Deleting section", "Брисање рубрика");
regGS("The section $1 has been deleted.", "Рубрика $1 је обрисана");
regGS("Configure section", "Подеси рубрику");
regGS("Updating section name", "Мењање имена рубрике");
regGS("The section could not be changed.", "Рубрика не може бити измењена");
regGS("Name<BR><SMALL>(click to add article)</SMALL>", "Назив <br><small>(кликните да додате текст)</small>");
regGS("Duplicate section", "Дуплирај рубрику");
regGS("The destination issue is the same as the source issue.", "Циљно издање је исто као матично.");
regGS("Error updating subscriptions.", "Грешка при мењању претплата.");
regGS("Duplicating section", "Дуплирање рубрике");
regGS("The section $1 could not be duplicated", "Рубрика  $1 не може бити дуплирана");
regGS("Section $1 has been duplicated to $2. $3 of $4", "рубрика $1 је дуплирана у $2. $3 од $4");
regGS("You do not have the right to modify sections.", "Немате право да мењате рубрике.");
regGS("Delete all articles from the section.", "Обриши све чланке из рубрике.");
regGS("A total of $1 articles were deleted.", "Укупно је обрисано $1 чланак(а).");
regGS("Duplicate Section:", "Дуплирај рубрику:");
regGS("Existing Section", "Рубрика постоји");
regGS("Go to new section", "Иди у нову рубрику");
regGS("Go to source section", "Иди у почетну рубрику");
regGS("New Section", "Нова рубрика");
regGS("Please select either '$1' or '$2'.", "Изаберите '$1' или '$2'.");
regGS("Select destination section:", "Изаберите циљну рубрику");
regGS("OR", "ИЛИ");
regGS("URL Name", "УРЛ име");
regGS("The section number specified already exists, please specify a different value or use the dropdown to find an existing section.", "Наведени број рубрике већ постоји - изаберите другу вредност или користите падајући мени за избор постојеће рубрике.");
regGS("Warning", "Упозорење");
regGS("You must select a section.", "Морате изабрати рубрику");
regGS("You must specify a name for the section.", "Морате унети име рубрике.");
regGS("Please check if another section with the same number does not already exist.", "Проверите да ли већ не постоји рубрика са истим бројем");
regGS("Short Name", "Скраћено име");
regGS("Destination section number", "Број циљне рубрике");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sr/sections.php <==
<?php
regGS("Section List", "Листа рубрика");
regGS("Section #$1 \"$2\" updated. (Publication: $3, Issue: $4)", "рубрика #$1 \"$2\" је измењена. (публикација: $3, издање: $4)");
regGS("Go To Articles", "Иди на текстове");
regGS("Add section to all subscriptions.", "Додај рубрику у све претплате.");
regGS("Delete section from all subscriptions.", "Обриши рубрику из свих претплата.");
regGS("A total of $1 subscriptions were updated.", "Укупан број измењених претплата: $1.");
regGS("Name<BR><SMALL>(click to see articles)</SMALL>", "Назив");
regGS("Delete section $1", "Обриши рубрику");
regGS("Adding new section", "Додавање нове рубрике");
regGS("You do not have the right to add sections.", "Немате право да додајете рубрике");
regGS("The section $1 has been successfuly added.", "Рубрика $1 успешно је додата");
regGS("Please check if another section with the same number or URL name does not exist already.", "Проверите да ли друга рубрика са истим бројем или УРЛ именом већ не постоји.");
regGS("Delete section", "Обриши рубрику");
regGS("You do not have the right to delete sections.", "Немате право брисања рубрика");
regGS("Are you sure you want to delete the section $1?", "Да ли сте сигурни да желите да обришете рубрику $1? ");
regGS("Deleting section", "Брисање рубрика");
regGS("The section $1 has been deleted.", "Рубрика $1 је обрисана");
regGS("Configure section", "Подеси рубрику");
regGS("Updating section name", "Мењање имена рубрике");
regGS("The section could not be changed.", "Рубрика не може бити измењена");
regGS("Duplicate section", "Дуплирај рубрику");
regGS("The destination issue is the same as the source issue.", "Циљно издање је исто као матично.");
regGS("Error updating subscriptions.", "Грешка при мењању претплата.");
regGS("Duplicating section", "Дуплирање рубрике");
regGS("The section $1 could not be duplicated", "Рубрика  $1 не може бити дуплирана");
regGS("Section $1 has been duplicated to $2. $3 of $4", "Рубрика $1 је дуплирана у $2. $3 од $4");
regGS("You do not have the right to modify sections.", "Немате право да мењате рубрике.");
regGS("Delete all articles from the section.", "Обриши све текстове из рубрике.");
regGS("A total of $1 articles were deleted.", "Укупно је обрисано $1 текст(ова).");
regGS("Duplicate Section:", "Дуплирај рубрику:");
regGS("Existing Section", "Рубрика постоји");
regGS("Go to new section", "Иди у нову рубрику");
regGS("Go to source section", "Иди у почетну рубрику");
regGS("New Section", "Нова рубрика");
regGS("Please select either '$1' or '$2'.", "Изаберите '$1' или '$2'.");
regGS("Select destination section:", "Изаберите циљну рубрику");
regGS("OR", "ИЛИ");
regGS("URL Name", "УРЛ име");
regGS("The section number specified already exists, please specify a different value or use the dropdown to find an existing section.", "Наведени број рубрике већ постоји - изаберите другу вредност или користите падајући мени за избор постојеће рубрике.");
regGS("Warning", "Упозорење");
regGS("You must select a section.", "Морате изабрати рубрику");
regGS("You must specify a name for the section.", "Морате унети име рубрике.");
regGS("Please check if another section with the same number does not already exist.", "Проверите да ли већ не постоји рубрика са истим бројем");
regGS("Short Name", "Скраћено име");
regGS("Destination section number", "Број циљне рубрике");
?>
